@@ -60,6 +60,19 @@ class Experiment(object):
     def __repr__(self):
         return '<Experiment: {0} (version: {1})>'.format(self.name, self.version())
 
+    def objectify_by_period(self, period):
+        objectified = {
+            'name': self.name,
+            'period': period,
+            'alternatives': []
+        }
+
+        for alternative in self.alternatives:
+            objectified_alt = alternative.objectify_by_period(period)
+            objectified['alternatives'].append(objectified_alt)
+
+        return objectified
+
     def initialize_alternatives(self, alternatives):
         for alternative_name in alternatives:
             if not Alternative.is_valid(alternative_name):
@@ -139,7 +152,7 @@ class Experiment(object):
 
         redis_results = pipe.execute()
         for idx, k in enumerate(keys):
-            stats[k] = redis_results[idx]
+            stats[k] = float(redis_results[idx])
 
         return stats
 
@@ -265,7 +278,7 @@ class Experiment(object):
         if random.random() < self.random_sample:
             return self._random_choice()
         else:
-           return Alternative(self._whiplash(), self, self.redis)
+            return Alternative(self._whiplash(), self, self.redis)
 
     def _random_choice(self):
         return random.choice(self.alternatives)
@@ -322,11 +335,17 @@ class Experiment(object):
             # If they are not, then we have to make a new version
             # above `experiment` is then returned eventually
             if sorted(current_alternatives) != sorted(alternatives):
-                exp.increment_version()
 
-                # initialize a new one
-                experiment = cls(experiment_name, alternatives, redis_conn)
-                experiment.save()
+                # First, let's try to find a version of the experiment that -did- have this argument list
+                found = Experiment.find_with_alternatives(experiment_name, alternatives, redis_conn)
+                if found is not None:
+                    experiment = found
+                else:
+                    exp.increment_version()
+
+                    # initialize a new one
+                    experiment = cls(experiment_name, alternatives, redis_conn)
+                    experiment.save()
             else:
                 experiment = exp
         # completely new experiment
@@ -336,6 +355,17 @@ class Experiment(object):
 
         return experiment
 
+    @classmethod
+    def find_with_alternatives(cls, experiment_name, alternatives, redis_conn):
+        versions = int(redis_conn.get(_key("experiments:{0}".format(experiment_name))))
+        for i in reversed(range(0, versions + 1)):
+            _a_key = _key("experiments:{0}/{1}:alternatives".format(experiment_name, i))
+            _alts = redis_conn.lrange(_a_key, 0, -1)
+            if sorted(_alts) == sorted(alternatives):
+                return cls(experiment_name, alternatives, redis_conn, i)
+
+        return None
+
     @staticmethod
     def all(redis_conn, exclude_archived=True):
         experiments = []
@@ -390,6 +420,42 @@ class Alternative(object):
     def __repr__(self):
         return "<Alternative {0} (Experiment {1})".format(self.name, self.experiment.name)
 
+    def objectify_by_period(self, period):
+
+        PERIOD_TO_METHOD_MAP = {
+            'day': {
+                'participants': self.participants_by_day,
+                'conversions': self.conversions_by_day
+            },
+            'month': {
+                'participants': self.participants_by_month,
+                'conversions': self.conversions_by_month
+            },
+            'year': {
+                'participants': self.participants_by_year,
+                'conversions': self.conversions_by_year
+            },
+        }
+
+        data = []
+        conversion_fn = PERIOD_TO_METHOD_MAP[period]['conversions']
+        participants_fn = PERIOD_TO_METHOD_MAP[period]['participants']
+
+        conversions = conversion_fn()
+        participants = participants_fn()
+
+        dates = sorted(list(set(conversions.keys() + participants.keys())))
+        for date in dates:
+            _data = {
+                'conversions': conversions.get(date, 0),
+                'participants': participants.get(date, 0),
+                'date': date
+            }
+            data.append(_data)
+
+        return {'name': self.name, 'data': data,
+                'control': self.is_control()}
+
     def is_control(self):
         return self.experiment.control().name == self.name
 
@@ -444,7 +510,7 @@ class Alternative(object):
 
         redis_results = pipe.execute()
         for idx, k in enumerate(keys):
-            stats[k] = redis_results[idx]
+            stats[k] = float(redis_results[idx])
 
         return stats
 
@@ -526,7 +592,7 @@ class Alternative(object):
 
         try:
             std_dev = pow(((ctr_e / pow(ctr_c, 3)) * ((e*ctr_e)+(c*ctr_c)-(ctr_c*ctr_e)*(c+e))/(c*e)), 0.5)
-            z_score = ((ctr_e / ctr_c) -1 ) / std_dev
+            z_score = ((ctr_e / ctr_c) - 1) / std_dev
             return z_score
         except ZeroDivisionError:
             return 0
